==> xoonips-3.30.tar.gz: xoonips-3.30/xoonips/admin/actions/common.inc.php <==
<?php
// $Revision: 1.1.2.6 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();

include '../condefs.php';
include '../class/base/tableobject.class.php';
include '../include/functions.php';

function xoonips_admin_initialize( $myfile, $preference, $pages ) {
  global $xoonips_admin;
  $xoonips_admin = array();
  $xoonips_admin['mydirname'] = basename( dirname( dirname( $myfile ) ) );
  $xoonips_admin['mod_url'] = XOOPS_URL.'/modules/'.$xoonips_admin['mydirname'];
  $xoonips_admin['mod_path'] = XOOPS_ROOT_PATH.'/modules/'.$xoonips_admin['mydirname'];
  $xoonips_admin['admin_url'] = $xoonips_admin['mod_url'].'/admin';
  $xoonips_admin['admin_path'] = $xoonips_admin['mod_path'].'/admin';
  $xoonips_admin['myfile_url'] = $xoonips_admin['admin_url'].'/'.basename( $myfile );
  // select page and action
  $page = ( isset( $_GET['page'] ) ) ? trim( $_GET['page'] ) : 'main';
  if ( ! in_array( $page, array_keys( $pages ) ) )
    die( 'illegal request' );
  $action = 'default';
  if ( isset( $_POST['action'] ) ) {
    $action = trim( $_POST['action'] );
  }
  if ( ! in_array( $action, $pages[$page] ) ) {
    die( 'illegal request' );
  }
  $xoonips_admin['myaction_path'] = 'actions/'.$preference.'_'.$page.'_'.$action.'.php';
  if ( ! file_exists( $xoonips_admin['myaction_path'] ) ) {
    die( 'illegal request' );
  }
  $xoonips_admin['mypage'] = $page;
  $xoonips_admin['myaction'] = $action;
  $xoonips_admin['mypage_url'] = $xoonips_admin['myfile_url'].'?page='.$xoonips_admin['mypage'];
}

function xoonips_admin_include_resource( $module, $file, $subdir=false ) {
  $lang = $GLOBALS['xoopsConfig']['language']; 
  $lang_en = 'english';
  if ( empty( $module ) ) {
    $lang_path = XOOPS_ROOT_PATH.'/language';
  } else {
    $lang_path = XOOPS_ROOT_PATH.'/modules/'.$module.'/language';
  }
  if ( empty( $subdir ) ) {
    $file_path = $lang_path.'/'.$lang.'/'.$file;
    if ( file_exists( $file_path ) ) {
      include $file_path;
    } else {
      include $lang_path.'/'.$lang_en.'/'.$file;
    }
  } else {
    $file_path = $lang_path.'/'.$lang.'/'.$subdir.'/'.$file;
    if ( file_exists( $file_path ) ) {
      include $file_path;
    } else {
      include $lang_path.'/'.$lang_en.'/'.$subdir.'/'.$file;
    }
  }
}

function xoonips_admin_sanitize_request( $type, $value ) {
  $myts =& MyTextSanitizer::getInstance();
  switch ( $type ) {
  case 's': // text
  case 'a': // text area
    $value = $myts->stripSlashesGPC( $value );
    break;
  case 'i': // int
    $value = intval( $value );
    break;
  case 'f': // float
    $value = floatval( $value );
    break;
  }
  return $value;
}

function xoonips_admin_get_requests( $request_type, $keys ) {
  global $xoonips_admin;
  $ret = array();
  foreach ( $keys as $key => $attributes ) {
    list( $data_type, $is_array, $required ) = $attributes;
    $value = null;
    switch( $request_type ) {
    case 'get' :
      $value = ( isset( $_GET[$key] ) ) ? $_GET[$key] : null;
      break;
    case 'post' :
      $value = ( isset( $_POST[$key] ) ) ? $_POST[$key] : null;
      break;
    case 'both' :
      $value = ( isset( $_REQUEST[$key] ) ) ? $_REQUEST[$key] : null;
      break;
    }
    // required check
    if ( $required ) {
      if ( is_null( $value ) ) {
	// debug
	// echo 'key : '.$key;
        // illegal request
        redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_MSG_ILLACCESS );
        exit();
      }
    }
    if ( is_null( $value ) ) {
      if ( $is_array ) {
        $value = array();
      }
    } else {
      if ( $is_array ) {
        foreach ( $value as $arrkey => $arrval ) {
          $value[$arrkey] = xoonips_admin_sanitize_request( $data_type, $arrval );
        }
      } else {
        $value = xoonips_admin_sanitize_request( $data_type, $value );
      }
    }
    $ret[$key] = $value;
  }
  return $ret;
}

function xoonips_admin_get_configs( $keys, $fmt ) {
  $myts =& MyTextSanitizer::getInstance();
  $xconfig_handler =& xoonips_getormhandler( 'xoonips', 'config' );
  $criteria = new CriteriaCompo();
  foreach ( array_keys( $keys ) as $key ) {
    $criteria->add( new Criteria( 'name', addslashes( $key ) ), 'OR' );
  }
  $objs =& $xconfig_handler->getObjects( $criteria );
  $ret = array();
  foreach ( $objs as $obj ) {
    $key =& $obj->getVar( 'name', 'n' );
    $var =& $obj->getVar( 'value', 'n' );
    switch ( $keys[$key] ) {
    case 's': // string
      switch( $fmt ) {
      case 's': case 'show':
      case 'e': case 'edit':
        $ret[$key] = $myts->htmlSpecialChars( $var );
        break;
      case 'p': case 'preview':
      case 'f': case 'formpreview':
        $ret[$key] = $myts->htmlSpecialChars( $myts->stripSlashesGPC( $var ) );
        break;
      case 'n': case 'none':
        $ret[$key] = $var;
      }
      break;
    case 'i': // int
      $ret[$key] = intval( $var );
      break;
    case 'f': // float
      $ret[$key] = floatval( $var );
      break;
    case 'a': // text area
      switch( $fmt ) {
      case 's': case 'show':
        $html = 1;
        $xcode = 0;
        $smiley = 0;
        $image = 0;
        $ret[$key] = $myts->displayTarea( $var, $html, $xcode, $smiley, $image, $br );
        break;
      case 'e': case 'edit':
        $ret[$key] = htmlspecialchars( $var, ENT_QUOTES );
        break;
      case 'p': case 'preview':
        $html = 1;
        $xcode = 0;
        $smiley = 0;
        $image = 0;
        $br = 1;
        $ret[$key] = $myts->previewTarea( $var, $html, $xcode, $smiley, $image, $br );
      case 'f': case 'formpreview':
        $ret[$key] = htmlspecialchars( $myts->stripSlashesGPC( $var ), ENT_QUOTES );
        break;
      case 'n': case 'none':
        $ret[$key] = $var;
      }
      break;
    }
  }
  return $ret;
}

function xoonips_admin_set_config( $name, &$value, $type ) {
  $myts =& MyTextSanitizer::getInstance();
  $xconfig_handler =& xoonips_getormhandler( 'xoonips', 'config' );
  $criteria = new Criteria( 'name', addslashes( $name ) );
  $objs = $xconfig_handler->getObjects( $criteria );
  if ( count( $objs ) != 1 ){
    return false;
  }
  list( $obj ) = $objs;
  switch ( $type ) {
  case 's': // string
  case 'a': // text area
    $cleanv = $myts->censorString( $value );
    break;
  case 'i': // int
    $cleanv = intval( $value );
    break;
  case 'f': // float
    $cleanv = floatval( $value );
    break;
  }
  $obj->setVar( 'value', $cleanv, true );
  return $xconfig_handler->insert( $obj );
}

?>

==> xoonips-3.32.tar.gz: xoonips-3.32/xoonips/admin/actions/common.inc.php <==
<?php
// $Revision: 1.1.2.10 $
//  ------------------------------------------------------------------------ //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2007 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
//  ------------------------------------------------------------------------ //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
//  ------------------------------------------------------------------------ //

if ( ! defined( 'XOOPS_ROOT_PATH' ) ) exit();

include '../condefs.php';
include '../include/functions.php';

function xoonips_admin_initialize( $myfile, $preference, $pages ) {
  global $xoonips_admin;
  $xoonips_admin = array();
  $xoonips_admin['mydirname'] = basename( dirname( dirname( $myfile ) ) );
  $xoonips_admin['mod_url'] = XOOPS_URL.'/modules/'.$xoonips_admin['mydirname'];
  $xoonips_admin['mod_path'] = XOOPS_ROOT_PATH.'/modules/'.$xoonips_admin['mydirname'];
  $xoonips_admin['admin_url'] = $xoonips_admin['mod_url'].'/admin';
  $xoonips_admin['admin_path'] = $xoonips_admin['mod_path'].'/admin';
  $xoonips_admin['myfile_url'] = $xoonips_admin['admin_url'].'/'.basename( $myfile );
  // select page and action
  $page = ( isset( $_GET['page'] ) ) ? trim( $_GET['page'] ) : 'main';
  if ( ! isset( $pages[$page] ) ) {
    die( 'illegal request' );
  }
  $actions =& $pages[$page];
  $action = 'default';
  $method = '';
  if ( isset( $_GET['action'] ) ) {
    $action = trim( $_GET['action'] );
    $method = 'get';
  } else if ( isset( $_POST['action'] ) ) {
    $action = trim( $_POST['action'] );
    $method = 'post';
  }
  if ( $action == '' ) {
    die( 'illegal request' ); 
  }
  if ( ! empty( $method ) ) {
    if ( ! isset( $actions[$method] ) ||
         ! in_array( $action, $actions[$method] ) ) {
      die( 'illegal request' );
    }
  }
  $xoonips_admin['myaction_path'] = 'actions/'.$preference.'_'.$page.'_'.$action.'.php';
  if ( ! file_exists( $xoonips_admin['myaction_path'] ) ) {
    die( 'illegal request' );
  }
  $xoonips_admin['mypage'] = $page;
  $xoonips_admin['myaction'] = $action;
  $xoonips_admin['mypage_url'] = $xoonips_admin['myfile_url'].'?page='.$xoonips_admin['mypage'];
}

function xoonips_admin_include_resource( $module, $file ) {
  $lang = $GLOBALS['xoopsConfig']['language']; 
  $lang_en = 'english';
  if ( empty( $module ) ) {
    $lang_path = XOOPS_ROOT_PATH.'/language';
  } else {
    $lang_path = XOOPS_ROOT_PATH.'/modules/'.$module.'/language';
  }
  $file_path = $lang_path.'/'.$lang.'/'.$file;
  if ( file_exists( $file_path ) ) {
    include_once $file_path;
  } else {
    include_once $lang_path.'/'.$lang_en.'/'.$file;
  }
}

function xoonips_admin_sanitize_request( $type, $value ) {
  $myts =& MyTextSanitizer::getInstance();
  switch ( $type ) {
  case 's': // text
  case 'a': // text area
    $value = $myts->stripSlashesGPC( $value );
    break;
  case 'i': // int
    $value = intval( $value );
    break;
  case 'f': // float
    $value = floatval( $value );
    break;
  }
  return $value;
}

function xoonips_admin_get_requests( $request_type, $keys ) {
  global $xoonips_admin;
  $ret = array();
  foreach ( $keys as $key => $attributes ) {
    list( $data_type, $is_array, $required ) = $attributes;
    $value = null;
    switch( $request_type ) {
    case 'get' :
      $value = ( isset( $_GET[$key] ) ) ? $_GET[$key] : null;
      break;
    case 'post' :
      $value = ( isset( $_POST[$key] ) ) ? $_POST[$key] : null;
      break;
    case 'both' :
      $value = ( isset( $_REQUEST[$key] ) ) ? $_REQUEST[$key] : null;
      break;
    }
    // required check
    if ( $required ) {
      if ( is_null( $value ) ) {
	// debug
	// echo 'key : '.$key;
        // illegal request
        redirect_header( $xoonips_admin['mypage_url'], 3, _AM_XOONIPS_MSG_ILLACCESS );
        exit();
      }
    }
    if ( is_null( $value ) ) {
      if ( $is_array ) {
        $value = array();
      }
    } else {
      if ( $is_array ) {
        foreach ( $value as $arrkey => $arrval ) {
          $value[$arrkey] = xoonips_admin_sanitize_request( $data_type, $arrval );
        }
      } else {
        $value = xoonips_admin_sanitize_request( $data_type, $value );
      }
    }
    $ret[$key] = $value;
  }
  return $ret;
}

function xoonips_admin_get_configs( $keys, $fmt ) {
  $myts =& MyTextSanitizer::getInstance();
  $xconfig_handler =& xoonips_getormhandler( 'xoonips', 'config' );
  $criteria = new CriteriaCompo();
  foreach ( array_keys( $keys ) as $key ) {
    $criteria->add( new Criteria( 'name', addslashes( $key ) ), 'OR' );
  }
  $objs =& $xconfig_handler->getObjects( $criteria );
  $ret = array();
  foreach ( $objs as $obj ) {
    $key =& $obj->getVar( 'name', 'n' );
    $var =& $obj->getVar( 'value', 'n' );
    switch ( $keys[$key] ) {
    case 's': // string
      switch( $fmt ) {
      case 's': case 'show':
      case 'e': case 'edit':
        $ret[$key] = $myts->htmlSpecialChars( $var );
        break;
      case 'p': case 'preview':
      case 'f': case 'formpreview':
        $ret[$key] = $myts->htmlSpecialChars( $myts->stripSlashesGPC( $var ) );
        break;
      case 'n': case 'none':
        $ret[$key] = $var;
      }
      break;
    case 'i': // int
      $ret[$key] = intval( $var );
      break;
    case 'f': // float
      $ret[$key] = floatval( $var );
      break;
    case 'a': // text area
      switch( $fmt ) {
      case 's': case 'show':
        $html = 1;
        $xcode = 0;
        $smiley = 0;
        $image = 0;
        $ret[$key] = $myts->displayTarea( $var, $html, $xcode, $smiley, $image, $br );
        break;
      case 'e': case 'edit':
        $ret[$key] = htmlspecialchars( $var, ENT_QUOTES );
        break;
      case 'p': case 'preview':
        $html = 1;
        $xcode = 0;
        $smiley = 0;
        $image = 0;
        $br = 1;
        $ret[$key] = $myts->previewTarea( $var, $html, $xcode, $smiley, $image, $br );
      case 'f': case 'formpreview':
        $ret[$key] = htmlspecialchars( $myts->stripSlashesGPC( $var ), ENT_QUOTES );
        break;
      case 'n': case 'none':
        $ret[$key] = $var;
      }
      break;
    }
  }
  return $ret;
}

function xoonips_admin_set_config( $name, &$value, $type ) {
  $myts =& MyTextSanitizer::getInstance();
  $xconfig_handler =& xoonips_getormhandler( 'xoonips', 'config' );
  $criteria = new Criteria( 'name', addslashes( $name ) );
  $objs = $xconfig_handler->getObjects( $criteria );
  if ( count( $objs ) != 1 ){
    return false;
  }
  list( $obj ) = $objs;
  switch ( $type ) {
  case 's': // string
  case 'a': // text area
    $cleanv = $myts->censorString( $value );
    break;
  case 'i': // int
    $cleanv = intval( $value );
    break;
  case 'f': // float
    $cleanv = floatval( $value );
    break;
  }
  $obj->setVar( 'value', $cleanv, true );
  return $xconfig_handler->insert( $obj );
}

?>
